# Dataset Class

The Dataset class manages versioned datasets in a Deriva catalog. Datasets are
collections of related data elements that can be versioned, downloaded as BDBags,
and tracked through their lifecycle.

::: deriva_ml.dataset.dataset
    handler: python
